import request from '@/utils/request'
// 分类数据获取
export function dataDictionaryGetTypeList(data) {
	return request({
		url: '/api/DataDictionary/GetTypeList',
		method: 'post',
		data,
	})
}
// 保存分类
export function dataDictionarySaveTypeData(data) {
	return request({
		url: '/Api/DataDictionary/SaveTypeData',
		method: 'post',
		data,
	})
}
// 分类详情	
export function dataDictionaryGetTypeData(data) {
	return request({
		url: '/api/DataDictionary/GetTypeData',
		method: 'post',
		data,
	})
}
// 分类删除	
export function dataDictionaryDelTypeData(data) {
	return request({
		url: '/api/DataDictionary/DelTypeData',
		method: 'post',
		data,
	})
}
// 数据字典列表
export function dataDictionaryGetBillList(data) {
	return request({
		url: '/api/DataDictionary/GetBillList',
		method: 'post',
		data,
	})
}
// 数据字典列表详情	
export function dataDictionaryGetBillData(data) {
	return request({
		url: '/api/DataDictionary/GetBillData',
		method: 'post',
		data,
	})
}
// 数据字典列表删保存
export function dataDictionarySaveData(data) {
	return request({
		url: '/Api/DataDictionary/SaveData',
		method: 'post',
		data,
	})
}
// 数据字典列表删除
export function DataDictionaryDelDatat(data) {
	return request({
		url: '/api/DataDictionary/DelData',
		method: 'post',
		data,
	})
}